==> buildpack-client-0.0.6-sources.jar: dev/snowdrop/buildpack/docker/StreamContentBuilder.java <==
package dev.snowdrop.buildpack.docker;

import dev.snowdrop.buildpack.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

 /**
  * Generated
  */
public class StreamContentBuilder extends dev.snowdrop.buildpack.docker.StreamContentFluentImpl<dev.snowdrop.buildpack.docker.StreamContentBuilder> implements dev.snowdrop.buildpack.builder.VisitableBuilder<dev.snowdrop.buildpack.docker.StreamContent,dev.snowdrop.buildpack.docker.StreamContentBuilder>{
  public StreamContentBuilder() {
    this(false);
  }
  public StreamContentBuilder(java.lang.Boolean validationEnabled) {
    this.fluent = this; this.validationEnabled=validationEnabled;
  }
  public StreamContentBuilder(dev.snowdrop.buildpack.docker.StreamContentFluent<?> fluent) {
    this(fluent, false);
  }
  public StreamContentBuilder(dev.snowdrop.buildpack.docker.StreamContentFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; this.validationEnabled=validationEnabled;
  }
  public StreamContentBuilder(dev.snowdrop.buildpack.docker.StreamContentFluent<?> fluent,dev.snowdrop.buildpack.docker.StreamContent instance) {
    this(fluent, instance, false);
  }
  public StreamContentBuilder(dev.snowdrop.buildpack.docker.StreamContentFluent<?> fluent,dev.snowdrop.buildpack.docker.StreamContent instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    this.validationEnabled = validationEnabled; 
  }
  public StreamContentBuilder(dev.snowdrop.buildpack.docker.StreamContent instance) {
    this(instance,false);
  }
  public StreamContentBuilder(dev.snowdrop.buildpack.docker.StreamContent instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.validationEnabled = validationEnabled; 
  }
  dev.snowdrop.buildpack.docker.StreamContentFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public dev.snowdrop.buildpack.docker.EditableStreamContent build() {
    EditableStreamContent buildable = new EditableStreamContent(fluent.getPath(),fluent.getSize(),fluent.getDataSupplier());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    StreamContentBuilder that = (StreamContentBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> buildpack-client-0.0.12-sources.jar: dev/snowdrop/buildpack/docker/StreamContentBuilder.java <==
package dev.snowdrop.buildpack.docker;

import dev.snowdrop.buildpack.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

 /**
  * Generated
  */
public class StreamContentBuilder extends dev.snowdrop.buildpack.docker.StreamContentFluentImpl<dev.snowdrop.buildpack.docker.StreamContentBuilder> implements dev.snowdrop.buildpack.builder.VisitableBuilder<dev.snowdrop.buildpack.docker.StreamContent,dev.snowdrop.buildpack.docker.StreamContentBuilder>{
  public StreamContentBuilder() {
    this(false);
  }
  public StreamContentBuilder(java.lang.Boolean validationEnabled) {
    this.fluent = this; this.validationEnabled=validationEnabled;
  }
  public StreamContentBuilder(dev.snowdrop.buildpack.docker.StreamContentFluent<?> fluent) {
    this(fluent, false);
  }
  public StreamContentBuilder(dev.snowdrop.buildpack.docker.StreamContentFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; this.validationEnabled=validationEnabled;
  }
  public StreamContentBuilder(dev.snowdrop.buildpack.docker.StreamContentFluent<?> fluent,dev.snowdrop.buildpack.docker.StreamContent instance) {
    this(fluent, instance, false);
  }
  public StreamContentBuilder(dev.snowdrop.buildpack.docker.StreamContentFluent<?> fluent,dev.snowdrop.buildpack.docker.StreamContent instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    this.validationEnabled = validationEnabled; 
  }
  public StreamContentBuilder(dev.snowdrop.buildpack.docker.StreamContent instance) {
    this(instance,false);
  }
  public StreamContentBuilder(dev.snowdrop.buildpack.docker.StreamContent instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.validationEnabled = validationEnabled; 
  }
  dev.snowdrop.buildpack.docker.StreamContentFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public dev.snowdrop.buildpack.docker.EditableStreamContent build() {
    EditableStreamContent buildable = new EditableStreamContent(fluent.getPath(),fluent.getSize(),fluent.getMode(),fluent.getDataSupplier());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    StreamContentBuilder that = (StreamContentBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}
